arm: actions: rename sysmap-s900 to sysmap-owl

Now that memory maps(for both S700 and S900 SoCs) can be managed using
a common file, rename sysmap-s900 to sysmap-owl to reflect the same.

Reviewed-by: Manivannan Sadhasivam <manivannan.sadhasivam@linaro.org>
Signed-off-by: Amit Singh Tomar <amittomer25@gmail.com>
diff --git a/arch/arm/mach-owl/Makefile b/arch/arm/mach-owl/Makefile
index 0b181c6..f3a69eb 100644
--- a/arch/arm/mach-owl/Makefile
+++ b/arch/arm/mach-owl/Makefile
@@ -1,4 +1,4 @@
 # SPDX-License-Identifier:	GPL-2.0+
 
 obj-y += soc.o
-obj-y += sysmap-s900.o
+obj-$(CONFIG_ARM64) += sysmap-owl.o
diff --git a/arch/arm/mach-owl/sysmap-s900.c b/arch/arm/mach-owl/sysmap-owl.c
similarity index 82%
rename from arch/arm/mach-owl/sysmap-s900.c
rename to arch/arm/mach-owl/sysmap-owl.c
index f78b639..81f6ca2 100644
--- a/arch/arm/mach-owl/sysmap-s900.c
+++ b/arch/arm/mach-owl/sysmap-owl.c
@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0+
 /*
  * Actions Semi S900 Memory map
  *
  * Copyright (C) 2015 Actions Semi Co., Ltd.
  * Copyright (C) 2018 Manivannan Sadhasivam <manivannan.sadhasivam@linaro.org>
@@ -9,7 +9,7 @@
 #include <common.h>
 #include <asm/armv8/mmu.h>
 
-static struct mm_region s900_mem_map[] = {
+static struct mm_region owl_mem_map[] = {
 	{
 		.virt = 0x0UL, /* DDR */
 		.phys = 0x0UL, /* DDR */
@@ -29,4 +29,4 @@
 	}
 };
 
-struct mm_region *mem_map = s900_mem_map;
+struct mm_region *mem_map = owl_mem_map;
@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0+
 /*
- * Actions Semi S900 Memory map
+ * Memory map for Actions Semi Owl series SoCs.
  *
  * Copyright (C) 2015 Actions Semi Co., Ltd.